# EnTrance

EnTrance is a framework for writing web apps, using a Python 3.5+ asyncio
backend, and an Elm frontend.

Communication between the frontend and backend is via JSON messages sent
asynchronously over a websocket.

This repo includes the Python package (published in PyPi) and also the Elm
package (published in elm-package).

A design document is in the `docs/` directory in the source repo; this
explains concepts and terminology required to fully understand the APIs
for both Elm and Python.
